@@ -50,7 +50,7 @@ def resource(public_id, **options):
   resource_type = options.pop("resource_type", "image")
   type = options.pop("type", "upload")
   uri = ["resources", resource_type, type, public_id]
-  return call_api("get", uri, only(options, "exif", "faces", "colors"), **options)
+  return call_api("get", uri, only(options, "exif", "faces", "colors", "max_results"), **options)
 
 def delete_resources(public_ids, **options):
   resource_type = options.pop("resource_type", "image")
@@ -59,8 +59,9 @@ def delete_resources(public_ids, **options):
   params = [("public_ids[]", public_id) for public_id in public_ids]
   return call_api("delete", uri, params, **options)
 
-def delete_resources_by_prefix(type, prefix, **options):
+def delete_resources_by_prefix(prefix, **options):
   resource_type = options.pop("resource_type", "image")
+  type = options.pop("type", "upload")
   uri = ["resources", resource_type, type]
   return call_api("delete", uri, {"prefix": prefix}, **options)      
 
