@@ -55,10 +55,15 @@ def generate_transformation_string(**options):
     effect = ":".join([str(x) for x in effect])
   elif isinstance(effect, dict):
     effect = ":".join([str(x) for x in effect.items()[0]])
-  params = {"w": width, "h": height, "t": named_transformation, "b": background, "e": effect, "c": crop, "a": angle}
+    
+  border = options.pop("border", None)
+  if isinstance(border, dict):
+    border = "%(width)spx_solid_%(color)s" % {"color": border.get("color", "black").replace("#", "rgb:"), "width": str(border.get("width", 2))}
+    
+  params = {"w": width, "h": height, "t": named_transformation, "b": background, "e": effect, "c": crop, "a": angle, "bo": border}
   for param, option in {"q": "quality", "g": "gravity", "p": "prefix", "x": "x",
                         "y": "y", "r": "radius", "d": "default_image", "l": "overlay", "u": "underlay",
-                        "f": "fetch_format", "pg": "page", "dn": "density"}.items():
+                        "f": "fetch_format", "pg": "page", "dn": "density", "dl": "delay", "cs": "color_space"}.items():
     params[param] = options.pop(option, None)
 
   transformations = [param + "_" + str(value) for param, value in params.items() if value]
